==> haskell-dependent-sum-template-0.1.1.1-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-Enhe3Gqo2IgJ2GBSKXvVFQ
key:                  dependent-sum-template-0.1.1.1-Enhe3Gqo2IgJ2GBSKXvVFQ
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  b107a3f73de910eb8f828035c49a399f
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-Enhe3Gqo2IgJ2GBSKXvVFQ
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-79jt0vPGn0W9EKZU3ruXRN
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-extras-0.0.0.8-Iwjg1lVEeHZIzj5KSvZ2oj

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-template-0.1.1.1-244-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum-template
version:              0.1.1.1
visibility:           public
id:                   dependent-sum-template-0.1.1.1-IK3zaBW8wNEAJMUbbebKdx
key:                  dependent-sum-template-0.1.1.1-IK3zaBW8wNEAJMUbbebKdx
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:
    Template Haskell code to generate instances of classes in dependent-sum package

description:
    Template Haskell code to generate instances of classes in dependent-sum package, such as '\''GEq'\'' and '\''GCompare'\''.

category:             Unclassified
abi:                  77d84c05137c7d025d4fc486290fe910
exposed:              True
exposed-modules:      Data.GADT.Compare.TH Data.GADT.Show.TH
hidden-modules:       Data.Dependent.Sum.TH.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/dependent-sum-template-0.1.1.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum-template
hs-libraries:         HSdependent-sum-template-0.1.1.1-IK3zaBW8wNEAJMUbbebKdx
depends:
    base-4.17.2.1 dependent-sum-0.7.2.0-DnGyB7JNULQ13d2EKAVbAY
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    th-extras-0.0.0.8-5jTyALxgksrDq0pxhnhuNZ

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum-template/html/dependent-sum-template.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum-template/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
